@@ -2,13 +2,21 @@
 # Licensed under the terms of the MIT License (see LICENSE.txt)
 
 import logging
+from django.core import urlresolvers
 from django.http import HttpResponse
 from django.shortcuts import render_to_response
 from django.template import RequestContext, loader
-from django.utils import simplejson
 from django.utils.translation import ugettext as _
 from tinymce.compressor import gzip_compressor
 from tinymce.widgets import get_language_config
+try:
+    import json
+except ImportError:
+    from django.utils import simplejson as json
+try:
+    from django.views.decorators.csrf import csrf_exempt
+except ImportError:
+    pass
 
 def textareas_js(request, name, lang=None):
     """
@@ -30,7 +38,6 @@ def textareas_js(request, name, lang=None):
     return HttpResponse(template.render(context),
             content_type="application/x-javascript")
 
-
 def spell_check(request):
     """
     Returns a HttpResponse that implements the TinyMCE spellchecker protocol.
@@ -39,7 +46,7 @@ def spell_check(request):
         import enchant
 
         raw = request.raw_post_data
-        input = simplejson.loads(raw)
+        input = json.loads(raw)
         id = input['id']
         method = input['method']
         params = input['params']
@@ -48,10 +55,11 @@ def spell_check(request):
 
         if not enchant.dict_exists(str(lang)):
             raise RuntimeError("dictionary not found for language '%s'" % lang)
-        checker = enchant.Dict(lang)
+
+        checker = enchant.Dict(str(lang))
 
         if method == 'checkWords':
-            result = [word for word in arg if not checker.check(word)]
+            result = [word for word in arg if word and not checker.check(word)]
         elif method == 'getSuggestions':
             result = checker.suggest(arg)
         else:
@@ -64,9 +72,28 @@ def spell_check(request):
     except Exception:
         logging.exception("Error running spellchecker")
         return HttpResponse(_("Error running spellchecker"))
-    return HttpResponse(simplejson.dumps(output),
+    return HttpResponse(json.dumps(output),
             content_type='application/json')
 
+try:
+    spell_check = csrf_exempt(spell_check)
+except NameError:
+    pass
+
+def preview(request, name):
+    """
+    Returns a HttpResponse whose content is an HTML file that is used
+    by the TinyMCE preview plugin. The template is loaded from
+    'tinymce/<name>_preview.html' or '<name>/tinymce_preview.html'.
+    """
+    template_files = (
+        'tinymce/%s_preview.html' % name,
+        '%s/tinymce_preview.html' % name,
+    )
+    template = loader.select_template(template_files)
+    return HttpResponse(template.render(RequestContext(request)),
+            content_type="text/html")
+
 
 def flatpages_link_list(request):
     """
@@ -102,9 +129,14 @@ def render_to_image_list(image_list):
     return render_to_js_vardef('tinyMCEImageList', image_list)
 
 def render_to_js_vardef(var_name, var_value):
-    output = "var %s = %s" % (var_name, simplejson.dumps(var_value))
+    output = "var %s = %s" % (var_name, json.dumps(var_value))
     return HttpResponse(output, content_type='application/x-javascript')
 
 def filebrowser(request):
-    return render_to_response('tinymce/filebrowser.js', {},
+    try:
+        fb_url = request.build_absolute_uri(urlresolvers.reverse('fb_browse'))
+    except:
+        fb_url = request.build_absolute_uri(urlresolvers.reverse('filebrowser:fb_browse'))
+
+    return render_to_response('tinymce/filebrowser.js', {'fb_url': fb_url},
             context_instance=RequestContext(request))
